==> flutter_agnes-1.0.0.tar.gz: lib/src/futures/future_build_widget.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_agnes/src/widgets/share/none_result.dart';
import 'package:flutter_agnes/src/widgets/share/waiting_result.dart';

import '../../flutter_agnes.dart';

typedef Widget BuilderWidget(dynamic itemData, int index);

enum ListType { LIST_VIEW, SLIVERS_LIST, ONE_WIDGET }

class FutureBuilderWidget<T> extends StatefulWidget {
  final Future<T> loadFuture;
  final String labelWaiting;
  final String labelNone;
  final BuilderWidget builderWidget;
  final ListType listType;
  final Color labelColor;
  final Color backgroundLabel;
  final bool shrinkWrap;
  final VoidCallback actionNoneResult;

  const FutureBuilderWidget({
    Key key,
    @required this.loadFuture,
    @required this.builderWidget,
    this.labelWaiting = 'Loading...',
    this.labelNone = 'Nenhum resultado encontrado!',
    this.listType = ListType.LIST_VIEW,
    this.labelColor = Colors.black,
    this.backgroundLabel = Colors.grey,
    this.shrinkWrap = false,
    this.actionNoneResult
  }) : super(key: key);

  @override
  _FutureBuilderWidgetState createState() => _FutureBuilderWidgetState();
}

class _FutureBuilderWidgetState<T> extends State<FutureBuilderWidget> {

  @override
  void initState() {
    super.initState();
  }

  _buildList(dynamic itemData, int count) {
    switch (widget.listType) {
      case ListType.LIST_VIEW:
        return ListView.builder(
          padding: EdgeInsets.zero,
          shrinkWrap: widget.shrinkWrap,
          physics: ClampingScrollPhysics(),
          itemCount: count,
          itemBuilder: (context, index) {
            return widget.builderWidget(itemData[index], index);
          },
        );

      case ListType.SLIVERS_LIST:
        return SliverList(
            delegate: SliverChildBuilderDelegate((context, index) {
              return widget.builderWidget(itemData[index], index);
            }, childCount: count));

      case ListType.ONE_WIDGET:
        return widget.builderWidget(itemData, 0);
    }
  }

  _waitingResult() {
    switch (widget.listType) {
      case ListType.LIST_VIEW:
        return WaitingResult(label: widget.labelWaiting, color: widget.labelColor);

      case ListType.SLIVERS_LIST:
        return SliverList(
          delegate: SliverChildListDelegate([WaitingResult(label: widget.labelWaiting, color: widget.labelColor)]),
        );

      case ListType.ONE_WIDGET:
        return WaitingResult(
            mainAxisAlignment: MainAxisAlignment.end,
            label: widget.labelWaiting,
            color: widget.labelColor,
            strokeWidth: 1,
            width: 10,
            height: 10);
    }
  }

  _noneResult() {
    final none = NoneResult(
      label: widget.labelNone,
      background: widget.backgroundLabel,
      color: widget.labelColor,
      onPressed: widget.actionNoneResult ?? ()=> setState(() {})
      ,
    );
    switch (widget.listType) {
      case ListType.LIST_VIEW:
        return none;

      case ListType.SLIVERS_LIST:
        return SliverList(
          delegate: SliverChildListDelegate([none]),
        );

      case ListType.ONE_WIDGET:
        return none;
    }
  }

  Widget _error(MessageModel messageModel) {
    switch (messageModel.code) {
      case 401:
        return SimpleDialogWidget(
          messageModel: messageModel,
          onPressed: widget.actionNoneResult ?? ()=> setState(() {})
        );
      default:
        return _noneResult();
    }
  }

  @override
  Widget build(BuildContext context) {
    return FutureBuilder(
        future: widget.loadFuture,
        builder: (context, snapshot) {
          switch (snapshot.connectionState) {
            case ConnectionState.none:
            case ConnectionState.waiting:
              return _waitingResult();
            case ConnectionState.active:
            case ConnectionState.done:
              int length = 0;
              if (snapshot.hasData) {
                if (widget.listType != ListType.ONE_WIDGET) length = snapshot.data.length;
                return _buildList(snapshot.data, length);
              } else if (snapshot.hasError) {
                return _error(snapshot.error);
              } else {
                return _noneResult();
              }
          }
          return WaitingResult(label: widget.labelWaiting);
        });
  }
}

==> flutter_agnes-1.0.1.tar.gz: lib/src/futures/future_build_widget.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_agnes/src/enums/enums_basic.dart';
import 'package:flutter_agnes/src/widgets/share/none_result.dart';
import 'package:flutter_agnes/src/widgets/share/waiting_result.dart';

import '../../flutter_agnes.dart';

typedef Widget BuilderWidget(dynamic itemData, int index);

//enum ListType { LIST_VIEW, SLIVERS_LIST, ONE_WIDGET }

class FutureBuilderWidget<T> extends StatefulWidget {
  final Future<T> loadFuture;
  final String labelWaiting;
  final String labelNone;
  final BuilderWidget builderWidget;
  final ListType listType;
  final Color labelColor;
  final Color backgroundLabel;
  final bool shrinkWrap;
  final VoidCallback actionNoneResult;

  const FutureBuilderWidget({
    Key key,
    @required this.loadFuture,
    @required this.builderWidget,
    this.labelWaiting = 'Loading...',
    this.labelNone = 'Nenhum resultado encontrado!',
    this.listType = ListType.LIST_VIEW,
    this.labelColor = Colors.black,
    this.backgroundLabel = Colors.grey,
    this.shrinkWrap = false,
    this.actionNoneResult
  }) : super(key: key);

  @override
  _FutureBuilderWidgetState createState() => _FutureBuilderWidgetState();
}

class _FutureBuilderWidgetState<T> extends State<FutureBuilderWidget> {

  @override
  void initState() {
    super.initState();
  }

  _buildList(dynamic itemData, int count) {
    switch (widget.listType) {
      case ListType.LIST_VIEW:
        return ListView.builder(
          padding: EdgeInsets.zero,
          shrinkWrap: widget.shrinkWrap,
          physics: ClampingScrollPhysics(),
          itemCount: count,
          itemBuilder: (context, index) {
            return widget.builderWidget(itemData[index], index);
          },
        );

      case ListType.SLIVERS_LIST:
        return SliverList(
            delegate: SliverChildBuilderDelegate((context, index) {
              return widget.builderWidget(itemData[index], index);
            }, childCount: count));

      case ListType.ONE_WIDGET:
        return widget.builderWidget(itemData, 0);
    }
  }

  _waitingResult() {
    switch (widget.listType) {
      case ListType.LIST_VIEW:
        return WaitingResult(label: widget.labelWaiting, color: widget.labelColor);

      case ListType.SLIVERS_LIST:
        return SliverList(
          delegate: SliverChildListDelegate([WaitingResult(label: widget.labelWaiting, color: widget.labelColor)]),
        );

      case ListType.ONE_WIDGET:
        return WaitingResult(
            mainAxisAlignment: MainAxisAlignment.end,
            label: widget.labelWaiting,
            color: widget.labelColor,
            strokeWidth: 1,
            width: 10,
            height: 10);
    }
  }

  _noneResult() {
    final none = NoneResult(
      label: widget.labelNone,
      background: widget.backgroundLabel,
      color: widget.labelColor,
      onPressed: widget.actionNoneResult ?? ()=> setState(() {})
      ,
    );
    switch (widget.listType) {
      case ListType.LIST_VIEW:
        return none;

      case ListType.SLIVERS_LIST:
        return SliverList(
          delegate: SliverChildListDelegate([none]),
        );

      case ListType.ONE_WIDGET:
        return none;
    }
  }

  Widget _error(MessageModel messageModel) {
    switch (messageModel.code) {
      case 401:
        return SimpleDialogWidget(
          messageModel: messageModel,
          onPressed: widget.actionNoneResult ?? ()=> setState(() {})
        );
      default:
        return _noneResult();
    }
  }

  @override
  Widget build(BuildContext context) {
    return FutureBuilder(
        future: widget.loadFuture,
        builder: (context, snapshot) {
          switch (snapshot.connectionState) {
            case ConnectionState.none:
            case ConnectionState.waiting:
              return _waitingResult();
            case ConnectionState.active:
            case ConnectionState.done:
              int length = 0;
              if (snapshot.hasData) {
                if (widget.listType != ListType.ONE_WIDGET) length = snapshot.data.length;
                return _buildList(snapshot.data, length);
              } else if (snapshot.hasError) {
                return _error(snapshot.error);
              } else {
                return _noneResult();
              }
          }
          return WaitingResult(label: widget.labelWaiting);
        });
  }
}
